Files
TheRock/debug-tools/rocgdb/source/gdb/testsuite/gdb.rocm/info-dispatches.cpp
T
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

97 lines
2.8 KiB
C++

/* Copyright (C) 2025 Free Software Foundation, Inc.
Copyright (C) 2025 Advanced Micro Devices, Inc. All rights reserved.
This file is part of GDB.
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>. */
#include <stdio.h>
#include <hip/hip_runtime.h>
#define CHECK(cmd) \
do \
{ \
hipError_t error = cmd; \
if (error != hipSuccess) \
{ \
fprintf (stderr, "error: '%s'(%d) at %s:%d\n", \
hipGetErrorString (error), error, __FILE__, __LINE__); \
exit (EXIT_FAILURE); \
} \
} \
while (0)
/* Make sure kernels running on STREAM are dispatched. */
#define flush_dispatch(STREAM) \
flush_dispatch_1 (STREAM, __FILE__, __LINE__)
static void
flush_dispatch_1 (hipStream_t stream, const char *file, int line)
{
hipError_t error = hipStreamQuery (stream);
if (error != hipSuccess && error != hipErrorNotReady)
{
fprintf (stderr, "error: '%s'(%d) at %s:%d\n",
hipGetErrorString (error), error, file, line);
exit (EXIT_FAILURE);
}
}
/* Two single-wave kernels to test `info dispatches` with
multiple dispatches. */
__global__ void
single_wave_kernel1 ()
{
}
__global__ void
single_wave_kernel2 ()
{
}
int
main (int argc, char* argv[])
{
const unsigned int numBlocks = 1;
const unsigned int numThreadsPerBlock = 1;
const unsigned int sharedMemBytes = 0;
hipStream_t stream1, stream2;
CHECK (hipStreamCreate (&stream1));
CHECK (hipStreamCreate (&stream2));
printf ("info: launch 'single_wave_kernel1' and 'single_wave_kernel2'\n");
single_wave_kernel1<<<numBlocks, numThreadsPerBlock, sharedMemBytes,
stream1>>> ();
single_wave_kernel2<<<numBlocks, numThreadsPerBlock, sharedMemBytes,
stream2>>> ();
/* Make sure both kernels are dispatched on Windows, otherwise they
may only be launched by the hipStreamSynchronize calls below, and
the first call would hang as kernel1 would be stopped at a
breakpoint. */
flush_dispatch (stream1);
flush_dispatch (stream2);
CHECK (hipStreamSynchronize (stream1));
CHECK (hipStreamSynchronize (stream2));
CHECK (hipStreamDestroy (stream1));
CHECK (hipStreamDestroy (stream2));
return 0;
}